@@ -14,49 +14,86 @@ import (
 )
 
 func TestCmdNew(t *testing.T) {
-	v := ui.NewPrompt(nil, true, config.NewStyles())
-	model := model.NewFishBuff(':', model.CommandBuffer)
-	v.SetModel(model)
-	model.AddListener(v)
-	for _, r := range "blee" {
-		model.Add(r)
+	uu := map[string]struct {
+		mode   rune
+		kind   model.BufferKind
+		noIcon bool
+		e      string
+	}{
+		"cmd": {
+			mode:   ':',
+			noIcon: true,
+			kind:   model.CommandBuffer,
+			e:      " > [::b]blee\n",
+		},
+
+		"cmd-ic": {
+			mode: ':',
+			kind: model.CommandBuffer,
+			e:    "🐶> [::b]blee\n",
+		},
+
+		"search": {
+			mode:   '/',
+			kind:   model.FilterBuffer,
+			noIcon: true,
+			e:      " / [::b]blee\n",
+		},
+
+		"search-ic": {
+			mode: '/',
+			kind: model.FilterBuffer,
+			e:    "🐩/ [::b]blee\n",
+		},
 	}
 
-	assert.Equal(t, "\x00> [::b]blee\n", v.GetText(false))
+	for k, u := range uu {
+		t.Run(k, func(t *testing.T) {
+			v := ui.NewPrompt(nil, u.noIcon, config.NewStyles())
+			m := model.NewFishBuff(u.mode, u.kind)
+			v.SetModel(m)
+			m.AddListener(v)
+			for _, r := range "blee" {
+				m.Add(r)
+			}
+			m.SetActive(true)
+			assert.Equal(t, u.e, v.GetText(false))
+		})
+	}
 }
 
 func TestCmdUpdate(t *testing.T) {
-	model := model.NewFishBuff(':', model.CommandBuffer)
+	m := model.NewFishBuff(':', model.CommandBuffer)
 	v := ui.NewPrompt(nil, true, config.NewStyles())
-	v.SetModel(model)
+	v.SetModel(m)
 
-	model.AddListener(v)
-	model.SetText("blee", "")
-	model.Add('!')
+	m.AddListener(v)
+	m.SetText("blee", "")
+	m.Add('!')
 
-	assert.Equal(t, "\x00> [::b]blee!\n", v.GetText(false))
+	assert.Equal(t, "\x00\x00 [::b]blee!\n", v.GetText(false))
 	assert.False(t, v.InCmdMode())
 }
 
 func TestCmdMode(t *testing.T) {
-	model := model.NewFishBuff(':', model.CommandBuffer)
+	m := model.NewFishBuff(':', model.CommandBuffer)
 	v := ui.NewPrompt(&ui.App{}, true, config.NewStyles())
-	v.SetModel(model)
-	model.AddListener(v)
+	v.SetModel(m)
+	m.AddListener(v)
 
 	for _, f := range []bool{false, true} {
-		model.SetActive(f)
+		m.SetActive(f)
 		assert.Equal(t, f, v.InCmdMode())
 	}
 }
 
 func TestPrompt_Deactivate(t *testing.T) {
-	model := model.NewFishBuff(':', model.CommandBuffer)
+	m := model.NewFishBuff(':', model.CommandBuffer)
 	v := ui.NewPrompt(&ui.App{}, true, config.NewStyles())
-	v.SetModel(model)
-	model.AddListener(v)
+	v.SetModel(m)
+	m.AddListener(v)
 
-	model.SetActive(true)
+	m.SetActive(true)
 	if assert.True(t, v.InCmdMode()) {
 		v.Deactivate()
 		assert.False(t, v.InCmdMode())
@@ -92,13 +129,13 @@ func TestPromptColor(t *testing.T) {
 	}
 
 	for _, testCase := range testCases {
-		model := model.NewFishBuff(':', testCase.kind)
+		m := model.NewFishBuff(':', testCase.kind)
 		prompt := ui.NewPrompt(&app, true, styles)
 
-		prompt.SetModel(model)
-		model.AddListener(prompt)
+		prompt.SetModel(m)
+		m.AddListener(prompt)
 
-		model.SetActive(true)
+		m.SetActive(true)
 		assert.Equal(t, testCase.expectedColor, prompt.GetBorderColor())
 	}
 }
@@ -135,17 +172,17 @@ func TestPromptStyleChanged(t *testing.T) {
 	}
 
 	for _, testCase := range testCases {
-		model := model.NewFishBuff(':', testCase.kind)
+		m := model.NewFishBuff(':', testCase.kind)
 		prompt := ui.NewPrompt(&app, true, styles)
 
-		model.SetActive(true)
+		m.SetActive(true)
 
-		prompt.SetModel(model)
-		model.AddListener(prompt)
+		prompt.SetModel(m)
+		m.AddListener(prompt)
 
 		prompt.StylesChanged(newStyles)
 
-		model.SetActive(true)
+		m.SetActive(true)
 		assert.Equal(t, testCase.expectedColor, prompt.GetBorderColor())
 	}
 }
